@@ -6,6 +6,7 @@ import { encodeXML, encodeHTML } from "./encode";
  *
  * @param data String to decode.
  * @param level Optional level to decode at. 0 = XML, 1 = HTML. Default is 0.
+ * @deprecated Use `decodeXML` or `decodeHTML` directly.
  */
 export function decode(data: string, level?: number): string {
     return (!level || level <= 0 ? decodeXML : decodeHTML)(data);
@@ -16,6 +17,7 @@ export function decode(data: string, level?: number): string {
  *
  * @param data String to decode.
  * @param level Optional level to decode at. 0 = XML, 1 = HTML. Default is 0.
+ * @deprecated Use `decodeHTMLStrict` or `decodeXML` directly.
  */
 export function decodeStrict(data: string, level?: number): string {
     return (!level || level <= 0 ? decodeXML : decodeHTMLStrict)(data);
@@ -26,6 +28,7 @@ export function decodeStrict(data: string, level?: number): string {
  *
  * @param data String to encode.
  * @param level Optional level to encode at. 0 = XML, 1 = HTML. Default is 0.
+ * @deprecated Use `encodeHTML`, `encodeXML` or `encodeNonAsciiHTML` directly.
  */
 export function encode(data: string, level?: number): string {
     return (!level || level <= 0 ? encodeXML : encodeHTML)(data);
@@ -34,8 +37,10 @@ export function encode(data: string, level?: number): string {
 export {
     encodeXML,
     encodeHTML,
+    encodeNonAsciiHTML,
     escape,
-    // Legacy aliases
+    escapeUTF8,
+    // Legacy aliases (deprecated)
     encodeHTML as encodeHTML4,
     encodeHTML as encodeHTML5,
 } from "./encode";
@@ -44,7 +49,7 @@ export {
     decodeXML,
     decodeHTML,
     decodeHTMLStrict,
-    // Legacy aliases
+    // Legacy aliases (deprecated)
     decodeHTML as decodeHTML4,
     decodeHTML as decodeHTML5,
     decodeHTMLStrict as decodeHTML4Strict,
